===========================
Murano Configuration Sample
===========================

The following is a sample murano configuration for adaptation and use. It is
auto-generated from murano when this documentation is built, so if you are
having issues with an option, please compare your version of murano with the
version of this documentation.

.. only:: html

   The sample configuration can also be downloaded in `file form <../_static/murano.conf.sample>`_.

.. literalinclude:: ../_static/murano.conf.sample
